==> common-utils-airport-1.0.2-20251030.020753-21-sources.jar: com/bizvane/utils/responseinfo/PageInfo.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014-2017 abel533@gmail.com
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
 * associated documentation files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
 * NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package com.bizvane.utils.responseinfo;

import lombok.Data;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

@Data
public class PageInfo<T> implements Serializable {

  private static final long serialVersionUID = 1L;

  private List<T> list = new ArrayList<>();

  // 当前页
  private int pageNum;
  // 每页的数量
  private int pageSize;

  // 总页数
  private int pages;

  // 总页数
  private long total;


  public PageInfo() {}


  public PageInfo(int pageNum, int pageSize, long total, List<T> list) {
    this.list = list;
    this.pageNum = pageNum;
    this.pageSize = pageSize;
    this.total = total;
    this.pages = (int) Math.ceil((double) total / pageSize);;
  }

}

==> common-utils-airport-20241112.123541-44-sources.jar: com/bizvane/utils/responseinfo/PageInfo.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014-2017 abel533@gmail.com
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
 * associated documentation files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
 * NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package com.bizvane.utils.responseinfo;

import lombok.Data;

import java.io.Serializable;
import java.util.List;

@Data
public class PageInfo<T> implements Serializable {

  private static final long serialVersionUID = 1L;

  private List<T> list;

  // 当前页
  private int pageNum;
  // 每页的数量
  private int pageSize;

  // 总页数
  private int pages;

  // 总页数
  private long total;


  public PageInfo() {}


  public PageInfo(int pageNum, int pageSize, long total, List<T> list) {
    this.list = list;
    this.pageNum = pageNum;
    this.pageSize = pageSize;
    this.total = total;
    this.pages = (int) Math.ceil((double) total / pageSize);;
  }

}
